@@ -220,13 +220,15 @@ class anim_text:
         self.obj.parent = parent
 
 
-    def animate(self, data, label, fix_place, if_str)
+    def animate(self, data, label, fix_place, if_str):
+        anim = self.anim
+
         if not(if_str):
             def update(self):
                 text = self.obj
                 cur_frame = bpy.context.scene.frame_current
                 
-                if np.any(cur_frame == self.anim.frames):
+                if np.any(cur_frame == anim.frames):
                     ind = np.where(cur_frame == anim.frames)[0][0]
                     text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
                     
